@@ -1,3 +1,3 @@
-from .meta_handler import MetaHandler
+from .meta_handler import MetaHandler, supported_meta_formats
 from .traceable import Traceable
 from .meta_handler import CustomEncoder as JSONEncoder
