@@ -3,7 +3,23 @@ from typing import List, Dict, Union
 
 
 class Traceable:
-    def __init__(self, *args, meta_prefix=None, **kwargs) -> None:
+    """
+    Base class for everything that has metadata in cascade.
+    Handles the logic of getting and updating internal meta prefix.
+    """
+    def __init__(self, *args, meta_prefix:Union[Dict, str] = None, **kwargs) -> None:
+        """
+        Parameters
+        ----------
+        meta_prefix: Union[Dict, str], optional
+            The dictionary that is used to update object's meta in `get_meta` call.
+            Due to the call of update can overwrite default values.
+            If str - prefix assumed to be path and loaded using MetaHandler.
+        
+        See also
+        --------
+        cascade.base.MetaHandler
+        """
         if meta_prefix is None:
             meta_prefix = {}
         elif isinstance(meta_prefix, str):
@@ -22,8 +38,8 @@ class Traceable:
         meta: List[Dict]
             A list where last element is this object's metadata.
             Meta can be anything that is worth to document about
-            the object and its properties. This is done in form
-            of list to enable cascade-like calls in Modifiers and Samplers.
+            the object and its properties.
+            Meta is list to allow the formation of pipelines.
         """
         meta = {
             'name': repr(self)
@@ -36,8 +52,8 @@ class Traceable:
 
     def update_meta(self, obj: Union[Dict, str]) -> None:
         """
-        Updates _meta_prefix, which is then updates
-        dataset's meta when get_meta() is called
+        Updates `_meta_prefix`, which then updates
+        dataset's meta when `get_meta()` is called
         """
         if isinstance(obj, str):
             obj = self._read_meta_from_file(obj)
