@@ -15,7 +15,7 @@ limitations under the License.
 """
 
 from numpy.random import random_integers, shuffle
-from . import Dataset, Sampler
+from . import Dataset, Sampler, T
 
 
 class RandomSampler(Sampler):
@@ -23,7 +23,7 @@ class RandomSampler(Sampler):
     Shuffles dataset. Can randomly sample from dataset
     if num_samples is not None and less than length of dataset.
     """
-    def __init__(self, dataset: Dataset, num_samples=None, **kwargs) -> None:
+    def __init__(self, dataset: Dataset, num_samples: int = None, **kwargs) -> None:
         """
         Parameters
         ----------
@@ -44,5 +44,5 @@ class RandomSampler(Sampler):
             self._indices = random_integers(0, len(dataset) - 1, num_samples)
         super().__init__(dataset, num_samples, **kwargs)
 
-    def __getitem__(self, index):
+    def __getitem__(self, index) -> T:
         return super().__getitem__(self._indices[index])
