@@ -21,22 +21,20 @@ from ..base import MetaHandler, JSONEncoder, supported_meta_formats
 
 class MetaViewer:
     """
-    The class to read and write meta data.
+    The class to view all metadata in folders and subfolders.
     """
-    def __init__(self, root, filt=None) -> None:
+    def __init__(self, root: str, filt: Dict=None) -> None:
         """
         Parameters
         ----------
-        root:
+        root: str
             path to the folder containing metadata files
-            to dump and load metadata files MetaHandler is used
         filt Dict, optional:
-            dictionary that specifies which values should be present in meta
+            dictionary that specifies which values that should be present in meta
             for example to find all models use `filt={'type': 'model'}`
 
         See also
         --------
-        cascade.meta.ModelRepo
         cascade.meta.MetaHandler
         """
         if not os.path.exists(root):
@@ -55,12 +53,12 @@ class MetaViewer:
         if filt is not None:
             self.names = list(filter(self._filter, self.names))
 
-    def __getitem__(self, index) -> List[Dict]:
+    def __getitem__(self, index: int) -> List[Dict]:
         """
         Returns
         -------
         meta: List[Dict]
-            object containing meta
+            Meta object
         """
         return self.read(self.names[index])
 
@@ -80,8 +78,8 @@ class MetaViewer:
         return self._mh.read(path)
 
     def _filter(self, name):
-        meta = self.read(name)
-        meta = meta[-1]  # Takes last meta
+        meta = self._mh.read(name)
+        meta = meta[0]  # Takes first meta which is last model's meta
         for key in self._filt:
             if key not in meta:
                 raise KeyError(f"'{key}' key is not in\n{meta}")
@@ -92,4 +90,7 @@ class MetaViewer:
 
     @staticmethod
     def obj_to_dict(obj):
+        """
+        Serializes the object using extended JSONEncoder
+        """
         return JSONEncoder().obj_to_dict(obj)
