@@ -21,13 +21,12 @@ import pytest
 MODULE_PATH = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
 sys.path.append(os.path.dirname(MODULE_PATH))
 
-from cascade.data import Wrapper
 from cascade.meta import DataValidationException, Validator, AggregateValidator, PredicateValidator
 
 
 def test_modifier_interface(number_dataset):
     ds = Validator(number_dataset, lambda x: True)
-    assert(number_dataset._data == [item for item in ds])
+    assert number_dataset._data == [item for item in ds]
 
 
 def test_aggregate_positive(number_dataset):
@@ -46,3 +45,18 @@ def test_predicate_positive(number_dataset):
 def test_predicate_negative(number_dataset):
     with pytest.raises(DataValidationException):
         ds = PredicateValidator(number_dataset, lambda x: x > float('inf'))
+
+
+def test_predicate_list_positive(number_dataset):
+    ds = PredicateValidator(number_dataset, [
+        lambda x: x < float('inf'),
+        lambda x: x < float('inf'),
+        lambda x: x < float('inf')])
+
+
+def test_predicate_list_negative(number_dataset):
+    with pytest.raises(DataValidationException):
+        ds = PredicateValidator(number_dataset, [
+            lambda x: x > float('inf'),
+            lambda x: x > float('inf'),
+            lambda x: x > float('inf')])
