@@ -19,6 +19,10 @@ class PaSchemaValidator(AggregateValidator):
             Schema of the table in the format that is acceptable by pandera
             or path to the YAML file with schema.
             For more details on schemas see pandera's documentation.
+        
+        Raises
+        ------
+        DataValidationException
         """
         super().__init__(dataset, *args, func=lambda x: self._validate(x, schema), **kwargs)
 
